/* Copyright (C) 2003 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef myx_library_h
#define myx_library_h

#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
  #define __LCC__
  #define _WINDOWS
#endif

#include "myx_public_interface.h"
#include "myx_util_functions.h"
#include "myx_shared_util_functions.h"

#define DBSTR(mysql, str) myx_convert_dbstr_utf8(mysql, str)

/*
 * Enums
 */


/*
 * Structs
 */


/*
 * Functions
 */

#endif

